%global _hardened_build 1

%global gh_commit    3a61c8b0b1cd846d0cd3a2c590a52fe9bc5974f7
%global gh_short     %(c=%{gh_commit}; echo ${c:0:7})
%global gh_owner     yrutschle
%global gh_project   sslh
%global with_tests   %{?_without_tests:0}%{!?_without_tests:1}

Name:    sslh
Version: 1.19c
Release: 1%{?dist}
Summary: Applicative protocol(SSL/SSH) multiplexer
License: GPLv2
Group:   Applications/System
URL:     https://github.com/%{gh_owner}/%{gh_project}
Source0: https://github.com/%{gh_owner}/%{gh_project}/archive/%{gh_commit}/%{gh_project}-%{version}-%{gh_short}.tar.gz

Patch1:   01-runasuser.patch
Patch2:   02-sysvinit-tuning.patch
Patch3:   03-remove-lcov-testing.patch

BuildRequires: libcap-devel
BuildRequires: libconfig-devel
BuildRequires: pkgconfig(libpcre)
BuildRequires: tcp_wrappers-devel

%if %{with_tests}
# Required for %%check
BuildRequires: perl(IO::Socket::INET6)
BuildRequires: perl(Test::More)
BuildRequires: valgrind
BuildRequires: psmisc
%else
: Skip upstream test suite
%endif

Requires(pre):   shadow-utils
Requires(post):  chkconfig
Requires(preun): chkconfig
Requires(preun): initscripts

%description
sslh accepts connections on specified ports, and forwards them further
based on tests performed on the first data packet sent by the remote
client.

Probes for HTTP, SSL, SSH, OpenVPN, tinc, XMPP are implemented, and
any other protocol that can be tested using a regular expression, can
be recognized. A typical use case is to allow serving several services
on port 443 (e.g. to connect to ssh from inside a corporate firewall,
which almost never block port 443) while still serving HTTPS on that port.

Hence sslh acts as a protocol multiplexer, or a switchboard. Its name
comes from its original function to serve SSH and HTTPS on the same port.


%prep
%setup -n %{name}-%{gh_commit}
%patch1 -p1
%patch2 -p1
%patch3 -p1

%build
./genver.sh >version.h
make %{?_smp_mflags} USELIBWRAP=1 USELIBCAP=1 sslh echosrv
pod2man --section=8 --release=%{version} --center=" " %{name}.pod > %{name}.8
iconv --from=ISO-8859-1 --to=UTF-8 ChangeLog > ChangeLog.conv && \
touch -r ChangeLog ChangeLog.conv && \
mv ChangeLog.conv ChangeLog

%install
rm -rf %{buildroot}
mkdir -p %{buildroot}%{_sbindir}
mkdir -p %{buildroot}%{_sysconfdir}
mkdir -p %{buildroot}%{_mandir}/man8
mkdir -p %{buildroot}%{_unitdir}
mkdir -p %{buildroot}%{_initddir}
mkdir -p %{buildroot}%{_sysconfdir}/sysconfig
mkdir -p %{buildroot}/var/run/%{name}
cp -p %{name}-fork %{buildroot}%{_sbindir}/%{name}
cp -p %{name}-select %{buildroot}%{_sbindir}/%{name}-select
cp -p %{name}.8 %{buildroot}%{_mandir}/man8/
cp -p scripts/etc.sysconfig.sslh %{buildroot}%{_sysconfdir}/sysconfig/sslh
cp -p basic.cfg %{buildroot}/%{_sysconfdir}/%{name}.cfg
cp -p scripts/etc.rc.d.init.d.sslh.centos %{buildroot}%{_initddir}/sslh

%check
%if %{with_tests}
# Use right ip6 localhost for Fedora
sed -i 's/ip6-localhost/localhost6/g' t
# Build the binaries with gcc coverage enabled
make test
%else
: Skip upstream test suite
%endif


%pre
getent group %{name} >/dev/null || groupadd -r %{name}
getent passwd %{name} >/dev/null || \
    useradd -r -g %{name} -d /dev/null -s /sbin/nologin \
    -c "SSLH daemon" %{name}
exit 0

%post
/sbin/chkconfig --add %{name}

%preun
if [ $1 -eq 0 ] ; then
    /sbin/service %{name} stop >/dev/null 2>&1
    /sbin/chkconfig --del %{name}
fi

%postun
if [ "$1" -ge "1" ] ; then
    /sbin/service %{name} condrestart >/dev/null 2>&1 || :
fi

%files
%doc README.md ChangeLog
%license COPYING
%{_mandir}/man8/%{name}.8*
%attr(0755,root,root) %{_sbindir}/%{name}
%attr(0755,root,root) %{_sbindir}/%{name}-select
%config(noreplace) %{_sysconfdir}/sysconfig/sslh
%config(noreplace) %attr(0644,root,root) %{_sysconfdir}/%{name}.cfg
%attr(0755,root,root) %{_initddir}/sslh
%dir %attr(0775,sslh,root) /var/run/%{name}

%changelog
* Wed Apr 18 2018 James Hogarth <james.hogarth@gmail.com> - 1.19c-1
- Update to 1.19c
- Drop el5 conditionals from spec

* Wed Mar 30 2016 James Hogarth <james.hogarth@gmail.com> - 1.18-1
- Update to 1.18 upstream release
- Add %%check to rpm spec
* Fri Jul 17 2015 James Hogarth <james.hogarth@gmail.com> - 1.17-2
- EL5 now has libconfig avaliable to it
- Consolidate spec files between el5 and el6
* Wed Mar 18 2015 James Hogarth <james.hogarth@gmail.com> - 1.17-1
- Initial packaging of sslh 1.17
